<?php
namespace AdaPay;

class AdaPay
{

    public static $api_key = "";
    public static $rsaPrivateKeyFilePath = "";
    public static $rsaPrivateKey = "";
    public static $rsaPublicKeyFilePath = "";
    public static $rsaPublicKey = "";

    public $gateWayUrl = "http://api.adapay.tech";
    public $header = array('Content-Type:application/json');
    public $headerText = array('Content-Type:text/html');
    public $apiVersion = "1.0";
    public $postCharset = "utf-8";
    public $signType = "RSA2";
    public $request = "";
    public $tools = "";
    public $statusCode = 200;
    public $result = array();

    public function __construct()
    {
        $this->request = new requests();
        $this->tools = new tools();
        $this->__init_params();
    }

    public static function setApiKey($api_key){
        self::$api_key =$api_key;
    }

    public static function setRsaPrivateKeyFilePath($path){
        self::$rsaPrivateKeyFilePath = $path;
    }

    public static function setRsaPrivateKey($priv_key){
        self::$rsaPrivateKey = $priv_key;
    }

    public static function setRsaPublicKeyFilePath($path){
        self::$rsaPublicKeyFilePath = $path;
    }

    public static function setRsaPublicKey($pub_key){
        self::$rsaPublicKey = $pub_key;
    }

    protected function __init_params(){
        $this->gateWayUrl = API_URL;
        $this->tools->rsaPrivateKeyFilePath = self::$rsaPrivateKeyFilePath;
        $this->tools->rsaPrivateKey = self::$rsaPrivateKey;
        $this->tools->rsaPublicKeyFilePath = self::$rsaPublicKeyFilePath;
        $this->tools->rsaPublicKey = self::$rsaPublicKey;
    }

    protected function get_request_header($req_url, $post_data, $header=array()){
        array_push($header, 'Authorization:'.self::$api_key);
        array_push($header, 'Signature:'.$this->tools->generateSignature($req_url, $post_data));
        return $header;
    }

    protected function handleResult(){
        $json_result_data = json_decode($this->result[1], true);
        if (isset($json_result_data['data'])){
            return json_decode($json_result_data['data'], true);
        }
        return [];
    }

    public function isError(){
        if (empty( $this->result )){
            return true;
        }
        $this->statusCode = $this->result[0];
        $resp_str = $this->result[1];
        $resp_arr = json_decode($resp_str, true);
        $resp_data = isset($resp_arr['data']) ? $resp_arr['data'] : '';
        $resp_sign = isset($resp_arr['signature']) ? $resp_arr['signature'] : '';
        $resp_data_decode = json_decode($resp_data, true);
        if ($resp_sign){
            if ($this->tools->verifySign($resp_sign, $resp_data)){
                if ($this->statusCode != 200){
                    $this->result = $resp_data_decode;
                    return true;
                }else{
                    $this->result = $resp_data_decode;
                    return false;
                }
            }else{
                $this->result = [
                    'failure_code'=> 'resp_sign_verify_failed',
                    'failure_msg'=> '接口返回签名验证失败',
                    'status'=> 'failed'
                ];
                return true;
            }
        }else{
            $this->result = $resp_arr;
            return true;
        }
    }
}