<?php
namespace AdaPay;
use Workerman\Worker;
use Workerman\Mqtt\Client;

class MessageSubscribe extends AdaPay
{
    public $worker;
    public $username;
    public $password;
    public $accessKey = "";
    public $instanceId = "";
    public $groupId = "";
    public $topic = "";
    public $clientId = "";
    public $client_address = "";
    public $token = "";
    public $callbackFunc = "";
    public $mq_token = NULL;

    public function __construct()
    {
        parent::__construct();
        $this->_init();
        $this->worker = new Worker();
        $this->mq_token = new MqttToken();
    }

    public function workerStart($workerMsg, $callback){
        $this->_setting();
        $topic = $this->topic;
        //启动一个任务进程
        $this->worker->onWorkerStart =  function () use ($topic,  $workerMsg, $callback){
            $options = array(
                'username'=>$this->username,
                'password'=>$this->_get_password(),
                'client_id'=> $this->clientId,
                'clean_session'=> false,
                'debug'=>true
            );

            $client = new Client('mqtt://'.$this->client_address, $options);
            $client->onConnect = function($mqtt) use ($topic) {
                $mqtt->subscribe($topic);
            };
            $client->onError = function ($exception){
                $this->worker->stopAll();
            };
            $client->onMessage = function($topic, $content) use ($workerMsg, $callback) {
                call_user_func(array($workerMsg, 'mqttCallBack'), $content, $callback);
            };
            //MQTT连接
            $client->connect();
        };
        $this->worker->runAll();
    }

    public  function mqttCallBack($content, $callback){
        $callback($content);
    }

    private function _init(){
        $this->accessKey = MQTT_ACCESS_KEY;
        $this->instanceId = MQTT_INSTANCE_ID;
        $this->groupId = MQTT_GROUP_ID;
        $this->client_address = MQTT_ADDRESS;
    }

    private function _get_password(){
        $token = $this->mq_token->getToken();
        return "R|".$token;
    }

    private function _setting(){
        $this->username = 'Token|' . $this->accessKey . '|' . $this->instanceId;
        $this->clientId = $this->groupId . '@@@' . md5(parent::$api_key.uniqid());
        $this->topic = "topic_crhs_sender/".parent::$api_key;
    }

}
